==> aws-java-sdk-opsworks-1.10.61-sources.jar: com/amazonaws/services/opsworks/model/transform/DescribeRdsDbInstancesRequestMarshaller.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.opsworks.model.transform;

import static com.amazonaws.util.StringUtils.UTF8;
import static com.amazonaws.util.StringUtils.COMMA_SEPARATOR;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.OutputStreamWriter;
import java.io.StringWriter;
import java.io.Writer;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.List;
import java.util.regex.Pattern;

import com.amazonaws.AmazonClientException;
import com.amazonaws.Request;
import com.amazonaws.DefaultRequest;
import com.amazonaws.http.HttpMethodName;
import com.amazonaws.services.opsworks.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.IdempotentUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.util.json.*;

/**
 * DescribeRdsDbInstancesRequest Marshaller
 */
public class DescribeRdsDbInstancesRequestMarshaller
        implements
        Marshaller<Request<DescribeRdsDbInstancesRequest>, DescribeRdsDbInstancesRequest> {

    public Request<DescribeRdsDbInstancesRequest> marshall(
            DescribeRdsDbInstancesRequest describeRdsDbInstancesRequest) {

        if (describeRdsDbInstancesRequest == null) {
            throw new AmazonClientException(
                    "Invalid argument passed to marshall(...)");
        }

        Request<DescribeRdsDbInstancesRequest> request = new DefaultRequest<DescribeRdsDbInstancesRequest>(
                describeRdsDbInstancesRequest, "AWSOpsWorks");
        request.addHeader("X-Amz-Target",
                "OpsWorks_20130218.DescribeRdsDbInstances");

        request.setHttpMethod(HttpMethodName.POST);

        request.setResourcePath("");

        try {
            StringWriter stringWriter = new StringWriter();
            JSONWriter jsonWriter = new JSONWriter(stringWriter);

            jsonWriter.object();

            if (describeRdsDbInstancesRequest.getStackId() != null) {
                jsonWriter.key("StackId").value(
                        describeRdsDbInstancesRequest.getStackId());
            }

            com.amazonaws.internal.SdkInternalList<String> rdsDbInstanceArnsList = (com.amazonaws.internal.SdkInternalList<String>) describeRdsDbInstancesRequest
                    .getRdsDbInstanceArns();
            if (!rdsDbInstanceArnsList.isEmpty()
                    || !rdsDbInstanceArnsList.isAutoConstruct()) {
                jsonWriter.key("RdsDbInstanceArns");
                jsonWriter.array();
                for (String rdsDbInstanceArnsListValue : rdsDbInstanceArnsList) {
                    if (rdsDbInstanceArnsListValue != null) {
                        jsonWriter.value(rdsDbInstanceArnsListValue);
                    }
                }
                jsonWriter.endArray();
            }

            jsonWriter.endObject();

            String snippet = stringWriter.toString();
            byte[] content = snippet.getBytes(UTF8);
            request.setContent(new StringInputStream(snippet));
            request.addHeader("Content-Length",
                    Integer.toString(content.length));
            request.addHeader("Content-Type", "application/x-amz-json-1.1");
        } catch (Throwable t) {
            throw new AmazonClientException(
                    "Unable to marshall request to JSON: " + t.getMessage(), t);
        }

        return request;
    }

}

==> aws-java-sdk-opsworks-1.10.64-sources.jar: com/amazonaws/services/opsworks/model/transform/DescribeRdsDbInstancesRequestMarshaller.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.opsworks.model.transform;

import static com.amazonaws.util.StringUtils.UTF8;
import static com.amazonaws.util.StringUtils.COMMA_SEPARATOR;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.OutputStreamWriter;
import java.io.StringWriter;
import java.io.Writer;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.List;
import java.util.regex.Pattern;

import com.amazonaws.AmazonClientException;
import com.amazonaws.Request;
import com.amazonaws.DefaultRequest;
import com.amazonaws.http.HttpMethodName;
import com.amazonaws.services.opsworks.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.IdempotentUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.util.json.*;

/**
 * DescribeRdsDbInstancesRequest Marshaller
 */
public class DescribeRdsDbInstancesRequestMarshaller
        implements
        Marshaller<Request<DescribeRdsDbInstancesRequest>, DescribeRdsDbInstancesRequest> {

    public Request<DescribeRdsDbInstancesRequest> marshall(
            DescribeRdsDbInstancesRequest describeRdsDbInstancesRequest) {

        if (describeRdsDbInstancesRequest == null) {
            throw new AmazonClientException(
                    "Invalid argument passed to marshall(...)");
        }

        Request<DescribeRdsDbInstancesRequest> request = new DefaultRequest<DescribeRdsDbInstancesRequest>(
                describeRdsDbInstancesRequest, "AWSOpsWorks");
        request.addHeader("X-Amz-Target",
                "OpsWorks_20130218.DescribeRdsDbInstances");

        request.setHttpMethod(HttpMethodName.POST);

        request.setResourcePath("");

        try {
            final SdkJsonGenerator jsonGenerator = new SdkJsonGenerator();

            jsonGenerator.writeStartObject();

            if (describeRdsDbInstancesRequest.getStackId() != null) {
                jsonGenerator.writeFieldName("StackId").writeValue(
                        describeRdsDbInstancesRequest.getStackId());
            }

            com.amazonaws.internal.SdkInternalList<String> rdsDbInstanceArnsList = (com.amazonaws.internal.SdkInternalList<String>) describeRdsDbInstancesRequest
                    .getRdsDbInstanceArns();
            if (!rdsDbInstanceArnsList.isEmpty()
                    || !rdsDbInstanceArnsList.isAutoConstruct()) {
                jsonGenerator.writeFieldName("RdsDbInstanceArns");
                jsonGenerator.writeStartArray();
                for (String rdsDbInstanceArnsListValue : rdsDbInstanceArnsList) {
                    if (rdsDbInstanceArnsListValue != null) {
                        jsonGenerator.writeValue(rdsDbInstanceArnsListValue);
                    }
                }
                jsonGenerator.writeEndArray();
            }

            jsonGenerator.writeEndObject();

            byte[] content = jsonGenerator.getBytes();
            request.setContent(new ByteArrayInputStream(content));
            request.addHeader("Content-Length",
                    Integer.toString(content.length));
            request.addHeader("Content-Type", "application/x-amz-json-1.1");
        } catch (Throwable t) {
            throw new AmazonClientException(
                    "Unable to marshall request to JSON: " + t.getMessage(), t);
        }

        return request;
    }

}
